"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PSBottomTabBar = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _reactNativeSkia = require("@shopify/react-native-skia");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// @ts-nocheck

const SCREEN_WIDTH = _reactNative.Dimensions.get('window').width;
const DEPTH = 52;
const TABBAR_HEIGHT = 91;
const PSBottomTabBar = _ref => {
  var _state$routes$state$i;
  let {
    state,
    navigation,
    descriptors,
    selectorStyle = {
      backgroundColor: '#fff',
      shadowColor: '#305F84'
    },
    topAreaStyle = {
      backgroundColor: '#1E1F23',
      shadowColor: '#000',
      shadowRate: 2
    },
    bottomAreaStyle = {
      backgroundColor: '#1B1C1E',
      shadowColor: '#000',
      shadowRate: 2
    }
  } = _ref;
  if (state.routes.length !== 5) {
    throw new Error('[PS-BOTTOM-TABBAR]: There must be 5 routes');
  }
  const {
    bottom: bottomSafe
  } = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const firstCircleR = 650;
  const selector = _reactNativeSkia.Skia.Path.Make();
  selector.moveTo(0, TABBAR_HEIGHT - 8);
  selector.quadTo(SCREEN_WIDTH / 2 - 13, TABBAR_HEIGHT - DEPTH - 13, SCREEN_WIDTH, TABBAR_HEIGHT - 8);
  const selectorStart = (0, _reactNativeSkia.useValue)(.06);
  const selectorEnd = (0, _reactNativeSkia.useValue)(.17);
  const calculateY = index => {
    if (index == 2) {
      return TABBAR_HEIGHT / 2 + 32;
    } else if (index == 3 || index == 1) {
      return TABBAR_HEIGHT / 2 + 24;
    } else {
      return TABBAR_HEIGHT / 2 + 12;
    }
  };
  const selectorPositions = [{
    selectorStartPosition: .06,
    selectorEndPosition: .18
  }, {
    selectorStartPosition: .25,
    selectorEndPosition: .37
  }, {
    selectorStartPosition: .44,
    selectorEndPosition: .56
  }, {
    selectorStartPosition: .63,
    selectorEndPosition: .75
  }, {
    selectorStartPosition: .82,
    selectorEndPosition: .94
  }];
  const onPress = async (route, index) => {
    const event = navigation.emit({
      type: 'tabPress',
      target: route.key,
      canPreventDefault: true
    });
    const isFocused = state.index === index;
    if (!isFocused && !event.defaultPrevented) {
      navigation.navigate(route.name);
      (0, _reactNativeSkia.runTiming)(selectorStart, selectorPositions[index].selectorStartPosition, {
        duration: 200
      });
      (0, _reactNativeSkia.runTiming)(selectorEnd, selectorPositions[index].selectorEndPosition, {
        duration: 200
      });
    }
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, {
      height: TABBAR_HEIGHT + bottomSafe
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Canvas, {
    style: {
      flex: 1
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Circle, {
    opacity: .85,
    cx: SCREEN_WIDTH / 2,
    cy: firstCircleR,
    r: firstCircleR,
    color: topAreaStyle.backgroundColor
  }, [...Array(topAreaStyle.shadowRate)].map((_, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
      key: index,
      dx: -15,
      dy: 0,
      blur: 45,
      color: topAreaStyle.shadowColor,
      inner: true
    });
  })), /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Circle, {
    cx: SCREEN_WIDTH / 2,
    cy: firstCircleR,
    r: firstCircleR - DEPTH,
    color: bottomAreaStyle.backgroundColor
  }, [...Array(bottomAreaStyle.shadowRate)].map((_, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
      key: index,
      dx: 0,
      dy: 0,
      blur: 24,
      color: bottomAreaStyle.shadowColor,
      inner: true
    });
  })), /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Path, {
    path: selector,
    color: selectorStyle.backgroundColor,
    style: "stroke",
    strokeWidth: 4,
    start: selectorStart,
    end: selectorEnd
  }, /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
    dx: -5,
    dy: -5,
    blur: 15,
    color: selectorStyle.shadowColor
  }), /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
    dx: -7,
    dy: -4,
    blur: 8,
    color: selectorStyle.shadowColor
  }), /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
    dx: 5,
    dy: -5,
    blur: 8,
    color: selectorStyle.shadowColor
  }), /*#__PURE__*/_react.default.createElement(_reactNativeSkia.Shadow, {
    dx: 7,
    dy: -4,
    blur: 8,
    color: selectorStyle.shadowColor
  }))), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.tabIcons
  }, state.routes.map((route, index) => {
    const {
      options
    } = descriptors[route.key] || {};
    return /*#__PURE__*/_react.default.createElement(TabIcon, {
      key: index,
      onPress: () => onPress(route, index),
      icon: options === null || options === void 0 ? void 0 : options.tabBarIcon,
      position: {
        x: SCREEN_WIDTH / 5 * index + 24,
        y: TABBAR_HEIGHT - calculateY(index)
      }
    });
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.textWrapper, {
      bottom: bottomSafe || 8
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      textAlign: 'center',
      color: 'white',
      fontSize: 16
    }
  }, (_state$routes$state$i = state.routes[state.index]) === null || _state$routes$state$i === void 0 ? void 0 : _state$routes$state$i.name))));
};
exports.PSBottomTabBar = PSBottomTabBar;
const TabIcon = _ref2 => {
  let {
    position,
    onPress,
    icon
  } = _ref2;
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    hitSlop: {
      top: 12,
      left: 12,
      bottom: 12,
      right: 12
    },
    onPress: onPress,
    style: [styles.icon, {
      top: position.y,
      left: position.x
    }]
  }, icon);
};
const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    bottom: 0,
    width: SCREEN_WIDTH
  },
  tabIcons: {
    flex: 1,
    backgroundColor: 'transparent',
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  },
  icon: {
    flex: 1,
    position: 'absolute',
    zIndex: -1,
    width: 36,
    height: 36
  },
  textWrapper: {
    position: 'absolute',
    right: 0,
    left: 0
  }
});
//# sourceMappingURL=index.js.map